@@ -30,7 +30,13 @@ from gettext import gettext as _
 LOG = logging.getLogger(__name__)
 
 from paths import (ONECONF_CACHE_DIR, OTHER_HOST_FILENAME, HOST_DATA_FILENAME, PENDING_UPLOAD_FILENAME,
-                   PACKAGE_LIST_PREFIX, LOGO_PREFIX, LOGO_BASE_FILENAME, LAST_SYNC_DATE_FILENAME)
+                   PACKAGE_LIST_PREFIX, LOGO_PREFIX, LOGO_BASE_FILENAME, LAST_SYNC_DATE_FILENAME, FAKE_WALLPAPER)
+
+# FIXME: ask about those horrible symlink to barry when I get time for it.
+try:
+    from oneconf import utils
+except ImportError:
+    import utils
 
 class HostError(Exception):
     def __init__(self, message):
@@ -51,7 +57,7 @@ class Hosts(object):
 
         # create cache dir if doesn't exist
         if not os.path.isdir(ONECONF_CACHE_DIR):
-            os.mkdir(ONECONF_CACHE_DIR)
+            os.makedirs(ONECONF_CACHE_DIR)
 
         (logo_checksum, logo_path) = self._get_current_wallpaper_data()
         
@@ -71,13 +77,16 @@ class Hosts(object):
                 if hostname != self.current_host['hostname']:
                     self.current_host['hostname'] = hostname
                     has_changed = True
+                if hostid != self.current_host['hostid']:
+                    self.current_host['hostid'] = hostid
+                    has_changed = True
                 if logo_checksum != self.current_host['logo_checksum']:
                     if (self._create_logo(logo_path)):
                         self.current_host['logo_checksum'] = logo_checksum
                     has_changed = True
             if has_changed:
                 self.save_current_host()
-        except IOError:
+        except (IOError, ValueError):
             self.current_host = {'hostid': hostid, 'hostname': hostname, 'share_inventory': False,
                                  'logo_checksum': logo_checksum, 'packages_checksum': None}
             if not os.path.isdir(self._host_file_dir):
@@ -90,8 +99,13 @@ class Hosts(object):
 
     def _get_current_wallpaper_data(self):
         '''Get current wallpaper metadatas from store'''
-        settings = Gio.Settings.new("org.gnome.desktop.background")
-        file_path = settings.get_string("picture-uri").replace("file://", "")
+        file_path = FAKE_WALLPAPER
+        if not file_path:
+            settings = Gio.Settings.new("org.gnome.desktop.background")
+            file_path = settings.get_string("picture-uri")
+        if not file_path:
+            return ('', '')
+        file_path = file_path.replace("file://", "")
         try:
             logo_checksum = "%s%f" % (hashlib.sha224(file_path).hexdigest(), os.stat(file_path).st_mtime)
         except OSError:
@@ -140,7 +154,7 @@ class Hosts(object):
         try:
             with open(os.path.join(self._host_file_dir, OTHER_HOST_FILENAME), 'r') as f:
                 return json.load(f)
-        except (IOError, TypeError), e:
+        except (IOError, TypeError, ValueError), e:
             LOG.warning("Error in loading %s file: %s" % (OTHER_HOST_FILENAME, e))
             return {}
 
@@ -148,8 +162,7 @@ class Hosts(object):
         '''Save current host on disk'''
         
         LOG.debug("Save current host to disk")
-        with open(os.path.join(self._host_file_dir, HOST_DATA_FILENAME), 'w') as f:
-            json.dump(self.current_host, f)
+        utils.save_json_file_update(os.path.join(self._host_file_dir, HOST_DATA_FILENAME), self.current_host)
 
     def add_hostid_pending_change(self, change):
         '''Pend a scheduled change for another host on disk
@@ -160,7 +173,7 @@ class Hosts(object):
         try:
             with open(os.path.join(self._host_file_dir, PENDING_UPLOAD_FILENAME), 'r') as f:
                 pending_changes = json.load(f)
-        except IOError:
+        except (IOError, ValueError):
             pending_changes = {}
 
         # merge existing changes with new ones
@@ -169,8 +182,7 @@ class Hosts(object):
                 pending_changes[hostid] = {}
             pending_changes[hostid].update(change[hostid])
 
-        with open(os.path.join(self._host_file_dir, PENDING_UPLOAD_FILENAME), 'w') as f:
-            json.dump(pending_changes, f)
+        utils.save_json_file_update(os.path.join(self._host_file_dir, PENDING_UPLOAD_FILENAME), pending_changes)
 
     def get_hostid_pending_change(self, hostid, attribute):
         '''Get the status if a pending change is in progress for an host
@@ -179,7 +191,7 @@ class Hosts(object):
         try:
             with open(os.path.join(self._host_file_dir, PENDING_UPLOAD_FILENAME), 'r') as f:
                 return json.load(f)[hostid][attribute]
-        except IOError, KeyError:
+        except (IOError, KeyError, ValueError) as e:
             return None
     
     def gethost_by_id(self, hostid):
@@ -263,6 +275,7 @@ class Hosts(object):
 
         if hostid or hostname:
             hostid = self.get_hostid_from_context(hostid, hostname)
+        if hostid and (hostid != self.current_host['hostid']):
             # do not update if there is already this pending change is already registered
             pending_change_scheduled = self.get_hostid_pending_change(hostid, 'share_inventory')
             if pending_change_scheduled != None:
@@ -293,5 +306,8 @@ class Hosts(object):
                 #last_sync = datetime.datetime.fromtimestamp(content['last_sync']).strftime("%X %x")
         except IOError:
             last_sync = _("Was never synced")
+        # FIXME: give a better sentence like "Last sync not completed successfully", but let's not add a translation right now
+        except ValueError:
+            last_sync = _("Was never synced")
         return last_sync
         
